@@ -53,4 +53,7 @@ def gcd(a, b):
             a = a % b
         else:
             b = b % a
-    return a + b
\ No newline at end of file
+    return a + b
+
+def lcm(a, b):
+    return int((a * b) / gcd(a, b))
\ No newline at end of file
